@@ -40,12 +40,6 @@ class BaseLunaUtils(object):
         register model
         """
 
-    @abstractmethod
-    def GetModelPath(self, context):
-        """
-        get model path
-        """
-
     @abstractmethod
     def DeployModel(self):
         """
