@@ -67,8 +67,10 @@ class LunaUtils(object):
         return args, userInput
 
     @staticmethod
-    def GetModelPath(run_type, context):
-        if run_type == 'azureml':
+    def GetModelPath(run_mode, context):
+        if run_mode == 'azureml':
             return os.getenv('AZUREML_MODEL_DIR')
+        elif run_mode == 'mlflow':
+            return context[MLFLOW_MODEL_PATH]
         else:
-            return context[MLFLOW_MODEL_PATH]
\ No newline at end of file
+            return 'models'
\ No newline at end of file
